@@ -73,6 +73,8 @@ class Element:
         return d
 
     def changeValue(self, c, v):
+        if c is None:
+            return v
         if type(c) is list:
             if type(v) is not c[-1]:
                 for _ in c:
@@ -81,21 +83,23 @@ class Element:
             v = c(v)
         return v
 
-    def useQtFunc(self, f, params):
+    def useQtFunc(self, f, params, ob=None):
         if type(params) is not list:
             params = [params]
         if type(f) is str:
+            #字符串则代表使用qt内置函数
             f = getattr(self.qt, f)
         else:
-            params.append(self)
+            #非字符串则表示使用自定义函数
+            params.extend([self, ob])
 
         f(*params)
 
     def addSubscribe(self, ob, c):
         if type(c[1]) is str:
-            ob.subscribe(lambda v: self.useQtFunc(c[0], c[1] % v), init=True)
+            ob.subscribe(lambda v: self.useQtFunc(c[0], c[1] % v, ob), init=True)
         else:
-            ob.subscribe(lambda v: self.useQtFunc(c[0], self.changeValue(c[1], v)), init=True)
+            ob.subscribe(lambda v: self.useQtFunc(c[0], self.changeValue(c[1], v), ob), init=True)
 
     def addEvent(self, e):
         event = getattr(self.qt, e.key)
@@ -113,6 +117,7 @@ class Element:
             _ = [*self.parser.ElementAttrConfig[self.name][k]]
             if isinstance(v, ObservableBase):
                 if attr.dom.attr('format'):
+                    #属性中包含format，则展现值是经过format处理的
                     _[1] = attr.dom.attr('format')
                 self.addSubscribe(v, _)
             else:
